@@ -4,7 +4,7 @@ import os
 
 from monty.re import regrep
 
-test_dir = os.path.join(os.path.dirname(__file__), "test_files")
+TEST_DIR = os.path.join(os.path.dirname(__file__), "test_files")
 
 
 def test_regrep():
@@ -13,7 +13,7 @@ def test_regrep():
     order, i.e. the first line that is read corresponds to the last line.
     number
     """
-    fname = os.path.join(test_dir, "3000_lines.txt")
+    fname = os.path.join(TEST_DIR, "3000_lines.txt")
     matches = regrep(fname, {"1": r"1(\d+)", "3": r"3(\d+)"}, postprocess=int)
     assert len(matches["1"]) == 1380
     assert len(matches["3"]) == 571
